import { ArchiveSource, BuildJob, Metadata, Platform } from '@expo/eas-build-job';
import { CredentialsSource } from '@expo/eas-json';
import { BuildContext } from './context';
import { ExpoGraphqlClient } from '../commandUtils/context/contextUtils/createGraphqlClient';
import { BuildFragment, BuildParamsInput } from '../graphql/generated';
import { BuildResult } from '../graphql/mutations/BuildMutation';
export interface CredentialsResult<Credentials> {
    source: CredentialsSource.LOCAL | CredentialsSource.REMOTE;
    credentials: Credentials;
}
export interface JobData<Credentials> {
    credentials?: Credentials;
    projectArchive: ArchiveSource;
}
interface Builder<TPlatform extends Platform, Credentials, TJob extends BuildJob> {
    ctx: BuildContext<TPlatform>;
    ensureCredentialsAsync(ctx: BuildContext<TPlatform>): Promise<CredentialsResult<Credentials> | undefined>;
    syncProjectConfigurationAsync(ctx: BuildContext<TPlatform>): Promise<void>;
    prepareJobAsync(ctx: BuildContext<TPlatform>, jobData: JobData<Credentials>): Promise<BuildJob>;
    sendBuildRequestAsync(appId: string, job: TJob, metadata: Metadata, buildParams: BuildParamsInput): Promise<BuildResult>;
}
export type BuildRequestSender = () => Promise<BuildFragment | undefined>;
export declare function prepareBuildRequestForPlatformAsync<TPlatform extends Platform, Credentials, TJob extends BuildJob>(builder: Builder<TPlatform, Credentials, TJob>): Promise<BuildRequestSender>;
export declare function handleBuildRequestError(error: any, platform: Platform): never;
export type MaybeBuildFragment = BuildFragment | null;
export declare function waitForBuildEndAsync(graphqlClient: ExpoGraphqlClient, { buildIds, accountName }: {
    buildIds: string[];
    accountName: string;
}, { intervalSec }?: {
    intervalSec?: number | undefined;
}): Promise<MaybeBuildFragment[]>;
export {};
