"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.generateProvisioningProfileAsync = exports.formatProvisioningProfileFromApple = void 0;
const tslib_1 = require("tslib");
const chalk_1 = tslib_1.__importDefault(require("chalk"));
const target_1 = require("../../../project/ios/target");
function formatProvisioningProfileFromApple(appleInfo) {
    const { expires, provisioningProfileId } = appleInfo;
    const id = provisioningProfileId ?? '-----';
    const name = appleInfo.name ?? '-----';
    const expiryString = expires ? new Date(expires * 1000).toDateString() : 'unknown';
    const details = chalk_1.default.green(`\n    Name: ${name}\n    Expiry: ${expiryString}`);
    return `Provisioning Profile - ID: ${id}${details}`;
}
exports.formatProvisioningProfileFromApple = formatProvisioningProfileFromApple;
async function generateProvisioningProfileAsync(ctx, target, bundleIdentifier, distCert) {
    const appleAuthCtx = await ctx.appStore.ensureAuthenticatedAsync();
    const type = appleAuthCtx.team.inHouse ? 'Enterprise ' : 'AppStore';
    const profileName = `*[expo] ${bundleIdentifier} ${type} ${new Date().toISOString()}`; // Apple drops [ if its the first char (!!)
    const applePlatform = await (0, target_1.getApplePlatformFromTarget)(target);
    return await ctx.appStore.createProvisioningProfileAsync(bundleIdentifier, distCert, profileName, applePlatform);
}
exports.generateProvisioningProfileAsync = generateProvisioningProfileAsync;
